.. include:: ../README.rst

Documentation Contents
----------------------
 
.. toctree::
   :maxdepth: 1

   installation
   usage
   api
   contributing


History
-------

.. include:: ../HISTORY.rst

.. include:: ../CODE_OF_CONDUCT.rst
